==========================
Joyous 0.9.5 release notes
==========================

.. contents::
    :local:
    :depth: 3


What's new
==========

Option to include started events in the upcoming list
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This release adds new setting :setting:`JOYOUS_UPCOMING_INCLUDES_STARTED`.
If this is set to ``True`` then the list of upcoming events will also include
events that have already started but have not yet finished.

New filters ``current`` for upcoming and started events and ``future``
for just upcoming events have been added to EventQuerySet.  The old
filter ``upcoming`` now just delegates to the appropriate one depending upon
:setting:`JOYOUS_UPCOMING_INCLUDES_STARTED`.

New event properties ``_current_datetime_from`` and ``_future_datetime_from``
are used by the filters and for sorting the list of events.
The old property ``_upcoming_datetime_from`` has been removed.

Wagtail 2.8
~~~~~~~~~~~
Support for Wagtail 2.8 (and Django 3.0).

Other features
~~~~~~~~~~~~~~
 * New :setting:`JOYOUS_FIRST_DAY_OF_WEEK` setting that will override Django's
   definition of the first day of the week if set.
 * Remove unneeded rss.ExtraInfoEntry.setImage()
 * Use naive datetimes in PostponementPage.what()
 * Dynamically copy postponements field values (should work for derieved classes too)

Bug fixes
~~~~~~~~~
 * Subtract page.num_days for continuuing events starting before fromDate
 * Force a call to _fetch_all in EventQuerySet.count()



Upgrade considerations
======================

 * The old property ``_upcoming_datetime_from`` has been removed.

